#!/bin/sh
##-----------------------------------------------------------------------------
## opt/files/usr/local/bin/faxsend.sh                             3.0.0
##
##        P L E A S E   R E A D   T H E   D O C U M E N T A T I O N ,
##
##        B I T T E  U N B E D I N G T   D I E   D O K U M E N T A T I O N
##
## Creation:     	Christian Raatz 0.1.1 fli4l@schinkensaft.de
## Last Update:	14.01.2006  jens kluge <jk@web.de>
## Support: 	Christian Schuermann, Joan Wolter, Felix Eckhofer (Many thanks!!!)
## Thx to:   	Thomas Unger, Thomas Klingler, Peter Schiefer, Manfred Schliesing
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##-----------------------------------------------------------------------------

#-------------------------------------------------------------------------
# connect to wan if offline and save in status_wan_old
#-------------------------------------------------------------------------
wan_connect ()
{
    # check whether router offline and save in status_wan_old
    status_dsl=`fli4lctrl status pppoe`
    status_isdn="offline"
    if [ `isdnctrl status all | grep to` ]
    then
	status_isdn="online"
    fi

    status_wan_old="offline"
    echo 

    case $status_dsl in
	online)
	    # DSL Online?
	    status_wan_old="online"
	    colecho "OPT_FAXSEND (Router war online (DSL)...." rd 0 br
	;;
    esac

    case $status_isdn in
	online)
	    # ISDN Online ?
	    status_wan_old="online"
	    colecho "OPT_FAXSEND (Router war online (ISDN)..." rd 0 br
	;;
    esac

    # connect if offline and test loop to be sure that it works
    # >>> bei faxprint hakelt der imonc
    status_wan_new="offline"
    if [ "$status_wan_old" = "offline" ]
    then
	colecho "OPT_FAXSEND Router war offline, Start online" rd 0 br
	while [ "$status_wan_new" = "offline" ]
	do
	    # connect to wan -> ONLINE
	    { echo "dial"; echo "quit"; } | netcat -w 1 127.0.0.1 $imond_port
	    # Test ob online
	    status_dsl=`fli4lctrl status pppoe`
	    if [ `isdnctrl status all | grep to` ]
	    then
            colecho "OPT_FAXSEND meldet online (ISDN) ...." gn 0 br
		status_isdn="online"
   	    fi

	    if [ "$status_dsl" = "online" ] 
	    then
		status_wan_new="online"
	    fi
	    if [ "$status_isdn" = "online" ] 
	    then
		status_wan_new="online"
	    fi
	    sleep 10 # schleife alle 10 sekunden wiederholen
	    colecho "OPT_FAXSEND Router meldet noch offline ...." rd 0 br
	done	  
	colecho "OPT_FAXSEND Router online !" gn 
    fi
}
# endof wan_connect



#-------------------------------------------------------------------------
# disconnect from wan(if offline at beginning) to wan
#-------------------------------------------------------------------------
wan_disconnect ()
{
    # gehe offline, wenn vor dem Faxversand offline war
    if [ "$status_wan_old" = "offline" ]
    then
	colecho "OPT_FAXSEND Router wieder offline nehmen" rd 0 br 
	while [ "$status_wan_new" = "online" ]
	do
	    { echo "hangup"; echo "quit"; } | netcat -w 1 127.0.0.1 $imond_port

	    # Test ob online
	    status_dsl=`fli4lctrl status pppoe`
	    if [ `isdnctrl status all | grep not` ]
	    then
		colecho "OPT_FAXSEND Router meldet OFFLINE (ISDN) " gn
		status_isdn="offline"
	    fi

	    if [ "$status_dsl" != "online" ] 
	    then
		if [ "$status_isdn" != "online" ] 
		then
		    status_wan_new="offline"
		fi   
	    fi

	    sleep 20 # schleife alle 20 sekunden wiederholen
	    colecho "OPT_FAXSEND Router meldet noch ONLINE ...." rd 0 br

	done	  
	colecho "OPT_FAXSEND Router offline !" gn

    else
	colecho "OPT_FAXSEND Router bleibt online !" rd 0 br
    fi
}
# endof wan_disconnect



#-------------------------------------------------------------------------
# send fax via email
#-------------------------------------------------------------------------
send_fax ()
{
    REDATE=
    case $customredate in
	yes) REDATE=`date` ;;
    esac

    # Kurzes einloggen auf dem pop3-server
    case $popcheck in
	yes)
	    colecho "OPT_FAXSEND $popsvr:$popport <$mailuser> (POPCHECK)" cy
	    echo -e "user $mailuser\npass $mailpwd\r\nquit"  |\
		netcat -i $waitsvr $popsvr $popport
	    colecho "OPT_FAXSEND popcheck fertig" gn
	;;
    esac

    # smtp.cmd vorbereiten 
    # Manfred Schliesing 07/2005: RFC Conform Mailadressen bermitteln
    # ----->  <$from> <$to> <$notifyaddr> 
    case $notifyonly in
	no) nach="$to" ;;
	*)  nach="$notifyaddr" ;;
    esac

    {
	cat <<EOF
helo $smtpsvr$CR
mail from: <$from>$CR
rcpt to: <$to>$CR
data$CR
Date: $DATE$CR
From: <$from>$CR
Reply-To: <$nach>$CR
To: <$nach>$CR
Subject: $customre $REDATE$CR
$CR
Fax wurde empfangen fuer $csid $CR
EOF

	# Fax versandfertig machen
	case ${notifyonly}${gzip}${format} in
	    noyessff) uuencode $fax $TIME.sff.gz ;;
	    nonosff)  gzip -dcfq $fax | uuencode $TIME.sff ;;
	    noyesjpeg) gzip -dcfq $fax > $TIME.sff; sff2misc -j $TIME.sff $TIME; gzip $TIME.001.jpg; uuencode $TIME.001.jpg.gz $TIME.jpg.gz; rm $TIME.001.jpg.gz; rm $TIME.sff ;;
	    nonojpeg) gzip -dcfq $fax > $TIME.sff; sff2misc -j $TIME.sff $TIME; uuencode $TIME.001.jpg $TIME.jpg; rm $TIME.001.jpg; rm $TIME.sff ;;
	    noyespdf) gzip -dcfq $fax > $TIME.sff; sff2misc -p $TIME.sff $TIME; /usr/local/bin/gs -q -dBATCH -dNOPAUSE -sDEVICE=pdfwrite -sOutputFile=$TIME.pdf /opt/files/usr/local/bin/margins.ps $TIME.ps; gzip $TIME.pdf; uuencode $TIME.pdf.gz $TIME.pdf.gz; rm $TIME.sff; rm $TIME.ps; rm $TIME.pdf.gz ;;
	    nonopdf) gzip -dcfq $fax > $TIME.sff; sff2misc -p $TIME.sff $TIME; /usr/local/bin/gs -q -dBATCH -dNOPAUSE -sDEVICE=pdfwrite -sOutputFile=$TIME.pdf /opt/files/usr/local/bin/margins.ps $TIME.ps; uuencode $TIME.pdf $TIME.pdf; rm $TIME.sff; rm $TIME.ps; rm $TIME.pdf ;;
	esac

	# smtp.cmd abschliessen
	cat <<EOF

$CR
.$CR
quit$CR
quit$CR
quit$CR
EOF
    }  > /tmp/smtp$TIME.cmd


    # Fax mit netcat verschicken
    colecho "OPT_FAXSEND $smtpsvr:$smtpport SEND $fax" cy
    colecho "OPT_FAXSEND from <$from> to <$nach>" cy
    netcat -w $waitsvr $smtpsvr $smtpport < /tmp/smtp$TIME.cmd
    colecho "OPT_FAXSEND Fax gesendet !" gn
}
# endof sendfax


#------------------------------------------------------------------------------
# delete fax after email sent
#------------------------------------------------------------------------------
del_fax ()
{

colecho "OPT_FAXSEND Remove Fax: $fax" gn

if [ -w $fax ]
then
	rm -f $fax
	if [ -e $fax ]
	then
		colecho "OPT_FAXSEND Remove Fax fehlgeschlagen!: $fax" rd
	else
		colecho "OPT_FAXSEND Fax removed ..." gn
		# ------------- mfax.log update von Felix bzw. Christian
		# ------------- begin mfax.log update
		filename=`basename $fax`
		directory=`dirname $fax`
		mfax=$directory'/mfax.log'
		sed -e "/$filename/d" $mfax > /tmp/mfax_tmp.log && mv /tmp/mfax_tmp.log $mfax
		# ------------- endof mfax.log update
	fi
else
	colecho "OPT_FAXSEND Remove Fax nicht moeglich fuer: $fax" rd
fi
}
# endof del_fax



#------------------------------------------------------------------------------
# SCRIPT START - Das Ganze erst mal vorbereiten
#------------------------------------------------------------------------------

colecho "OPT_FAXSEND: start faxsend.sh ..." gn 0 br

imond_port=`cat /var/run/imond.port`
CR=`echo -e '\r'`
fax=
idx=

# read configuration
. /var/run/faxsend.conf

exec > $FAXSEND_REDIRECT 2>&1

while [ "$1" ]
do
    case $1 in
	*[^0-9]*)

	    fax=$1
	    colecho "OPT_FAXSEND Parameter Fax: $fax" cy
	    case x$2 in
		x) csid=$FAXRCV_CSID 
		   colecho "OPT_FAXSEND Parameter FAXRCV_CSID: $csid" cy 			
		   ;; 
		*) csid=$2 
		   colecho "OPT_FAXSEND Parameter 2: $2" cy 
		   ;;
	    esac
	    break 
	    ;;

	*)
   	    idx="$idx $1" 
	    colecho "OPT_FAXSEND Parameter idx: $idx" cy 	
	    ;;
    esac
    shift
done

case $OPT_FAXSEND in
    yes) ;;
    *)
	colecho "OPT_FAXSEND disabled"
	exit 
	;;
esac

if [ 0$FAXSEND_N -eq 0 ]
then
    colecho "OPT_FAXSEND: faxsend_n=0"
    exit 
fi

DATE=`date`                                  
TIME=`date +%y%m%d%H%M`
onlinecheck=$FAXSEND_ONLINECHECK

# ------------------
# connect if offline
# ------------------
if [ "$onlinecheck" = "yes" ]
then
	colecho "OPT_FAXSEND onlinecheck: $onlinecheck" cy
	wan_connect
fi

for idx in $idx
do
    if set | grep -q ^FAXSEND_${idx}_FROM
    then
	eval from='$FAXSEND_'$idx'_FROM'
	eval to='$FAXSEND_'$idx'_TO'
	eval popcheck='$FAXSEND_'$idx'_POPCHECK'
	eval gzip='$FAXSEND_'$idx'_GZIP'
	eval mailuser='$FAXSEND_'$idx'_MAILUSER'
	eval mailpwd='$FAXSEND_'$idx'_MAILPWD'
	eval popsvr='$FAXSEND_'$idx'_POPSVR'
	eval popport='$FAXSEND_'$idx'_POPPORT'
	eval smtpsvr='$FAXSEND_'$idx'_SMTPSVR'
	eval smtpport='$FAXSEND_'$idx'_SMTPPORT'
	eval waitsvr='$FAXSEND_'$idx'_WAITSVR'
	eval notifyonly='$FAXSEND_'$idx'_NOTIFYONLY'
	eval notifyaddr='$FAXSEND_'$idx'_NOTIFYADDR'
	eval customre='$FAXSEND_'$idx'_CUSTOMRE'
	eval customredate='$FAXSEND_'$idx'_CUSTOMREDATE'
	eval delfax='$FAXSEND_'$idx'_DELFAX'
	eval format='$FAXSEND_'$idx'_FORMAT'
	# get csid from opt_faxrcv
	# eval csid='$FAXRCV_'$idx'_CSID'  # doppelt ???? da bereits als Argument bergeben ?????
      # colecho "OPT_FAXSEND Parameter FAXRCV_idx csid: $csid" cy 

	# ---------
	# send_fax
	# ---------
	send_fax

    else
	colecho "OPT_FAXSEND: ignoring invalid configuration $idx"
    fi
done

# ----------------------------------
# disconnect if offline at beginning
# ----------------------------------
if [ "$onlinecheck" = "yes" ]
then
	colecho "OPT_FAXSEND onlinecheck: $onlinecheck" cy
	wan_disconnect
fi

# check whether fax on router shall be deleted and delete if delfax is yes
delete_fax="yes"
for idx in $idx
do
    if set | grep -q ^FAXSEND_${idx}_FROM
    then
	eval delfax='$FAXSEND_'$idx'_DELFAX'
    	if [ "$delfax" = "no" ]
    	then
		colecho "OPT_FAXSEND DELFAX idx =no: $idx" cy
    		delete_fax="no"
	fi
    fi
done 

if [ "$delete_fax" = "yes" ]
then
	colecho "OPT_FAXSEND DELFAX: $deletefax" cy
	# ---------
	# del_fax
	# ---------
	del_fax
fi

# Temporaere Dateien loeschen
colecho "OPT_FAXSEND Temporaere Dateien loeschen ....." cy
rm -f /tmp/smtp$TIME.cmd  /tmp/faxtmp.sff
colecho "OPT_FAXSEND Temporaere Dateien geloescht !" gn



